"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = useDateInput;
var _dateUtils = require("./dateUtils");
var React = _interopRequireWildcard(require("react"));
var _utils = require("../translations/utils");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function useDateInput({
  locale,
  value,
  validRange,
  inputMode,
  onChange,
  onValidationError
}) {
  const {
    isDisabled,
    isWithinValidRange,
    validStart,
    validEnd
  } = (0, _dateUtils.useRangeChecker)(validRange);
  const [error, setError] = React.useState(null);
  const formatter = (0, _dateUtils.useInputFormatter)({
    locale
  });
  const inputFormat = (0, _dateUtils.useInputFormat)({
    formatter,
    locale
  });
  const formattedValue = value ? formatter.format(value) : '';
  const onChangeText = date => {
    const dayIndex = inputFormat.indexOf('DD');
    const monthIndex = inputFormat.indexOf('MM');
    const yearIndex = locale === 'pt' ? inputFormat.indexOf('AAAA') : inputFormat.indexOf('YYYY');
    const day = Number(date.slice(dayIndex, dayIndex + 2));
    const year = Number(date.slice(yearIndex, yearIndex + 4));
    const month = Number(date.slice(monthIndex, monthIndex + 2));
    if (Number.isNaN(day) || Number.isNaN(year) || Number.isNaN(month)) {
      const inputError = (0, _utils.getTranslation)(locale, 'notAccordingToDateFormat', () => 'notAccordingToDateFormat')(inputFormat);
      setError(inputError);
      onValidationError && onValidationError(inputError);
      return;
    }
    const finalDate = inputMode === 'end' ? new Date(year, month - 1, day, 23, 59, 59) : new Date(year, month - 1, day);
    if (isDisabled(finalDate)) {
      const inputError = (0, _utils.getTranslation)(locale, 'dateIsDisabled');
      setError(inputError);
      onValidationError && onValidationError(inputError);
      return;
    }
    if (!isWithinValidRange(finalDate)) {
      let errors = validStart && validEnd ? [`${(0, _utils.getTranslation)(locale, 'mustBeBetween', () => 'mustBeBetween')(formatter.format(validStart), formatter.format(validEnd))}`] : [validStart ? (0, _utils.getTranslation)(locale, 'mustBeHigherThan', () => 'mustBeHigherThan')(formatter.format(validStart)) : '', validEnd ? (0, _utils.getTranslation)(locale, 'mustBeLowerThan', () => 'mustBeLowerThan')(formatter.format(validEnd)) : ''];
      const inputError = errors.filter(n => n).join(' ');
      setError(errors.filter(n => n).join(' '));
      onValidationError && onValidationError(inputError);
      return;
    }
    setError(null);
    onValidationError && onValidationError(null);
    if (inputMode === 'end') {
      onChange(finalDate);
    } else {
      onChange(finalDate);
    }
  };
  return {
    onChange,
    error,
    formattedValue,
    onChangeText,
    inputFormat
  };
}
//# sourceMappingURL=inputUtils.js.map